#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-happy-lib-z-grammar
version:              2.1.6
package-name:         happy-lib
lib-name:             grammar
id:                   happy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar
key:                  happy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar
license:              BSD-2-Clause
copyright:            (c) Andy Gill, Simon Marlow
maintainer:           https://github.com/haskell/happy
author:               Andy Gill and Simon Marlow
stability:            stable
homepage:             https://www.haskell.org/happy/
synopsis:
    Happy is a parser generator for Haskell implemented using this library

description:
    Happy is a parser generator for Haskell.  Given a grammar
    specification in BNF, Happy generates Haskell code to parse the
    grammar.  Happy works in a similar way to the @yacc@ tool for C.

    This library provides the following functionality:

      * Data type definitions for the Grammar AST type, capturing the information in .y-files (Happy.Grammar)

      * A parser for happy grammar files (.y) to produce a Grammar (Happy.Frontend.*)

      * Implementations of the text book algorithms that compute the LR action and
        goto tables for the given '\''Grammar'\'' (Happy.Tabular.*)

      * An LALR code generator to produce table-driven, deterministic parsing code
        in Haskell (Happy.Backend.LALR.*)

      * A (less maintained) GLR code generator to produce table-driven,
        non-deterministic parsing code in Haskell, where ambiguous parses produce
        multiple parse trees (Happy.Backend.GLR.*)

category:             Development
abi:                  8b6511977720b23d8391010dccb4f4b6
exposed-modules:      Happy.Grammar Happy.Grammar.ExpressionWithHole
import-dirs:          /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happy-lib
hs-libraries:         HShappy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar
depends:              array-0.5.6.0 base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-happy-lib/html/happy-lib.haddock
haddock-html:         /usr/share/doc/haskell-happy-lib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-happy-lib-z-tabular
version:              2.1.6
package-name:         happy-lib
lib-name:             tabular
id:                   happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular
key:                  happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular
license:              BSD-2-Clause
copyright:            (c) Andy Gill, Simon Marlow
maintainer:           https://github.com/haskell/happy
author:               Andy Gill and Simon Marlow
stability:            stable
homepage:             https://www.haskell.org/happy/
synopsis:
    Happy is a parser generator for Haskell implemented using this library

description:
    Happy is a parser generator for Haskell.  Given a grammar
    specification in BNF, Happy generates Haskell code to parse the
    grammar.  Happy works in a similar way to the @yacc@ tool for C.

    This library provides the following functionality:

      * Data type definitions for the Grammar AST type, capturing the information in .y-files (Happy.Grammar)

      * A parser for happy grammar files (.y) to produce a Grammar (Happy.Frontend.*)

      * Implementations of the text book algorithms that compute the LR action and
        goto tables for the given '\''Grammar'\'' (Happy.Tabular.*)

      * An LALR code generator to produce table-driven, deterministic parsing code
        in Haskell (Happy.Backend.LALR.*)

      * A (less maintained) GLR code generator to produce table-driven,
        non-deterministic parsing code in Haskell, where ambiguous parses produce
        multiple parse trees (Happy.Backend.GLR.*)

category:             Development
abi:                  03601e460f3e81a6b590dccbda38472d
exposed-modules:
    Happy.Paths from happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular:Paths_happy_lib,
    Happy.Tabular, Happy.Tabular.First, Happy.Tabular.Info,
    Happy.Tabular.LALR, Happy.Tabular.NameSet, Paths_happy_lib

import-dirs:          /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happy-lib
hs-libraries:         HShappy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    happy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar

haddock-interfaces:   /usr/share/doc/haskell-happy-lib/html/happy-lib.haddock
haddock-html:         /usr/share/doc/haskell-happy-lib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-happy-lib-z-frontend
version:              2.1.6
package-name:         happy-lib
lib-name:             frontend
id:                   happy-lib-2.1.6-7bjb9RLGTaSLO5wawgkRup-frontend
key:                  happy-lib-2.1.6-7bjb9RLGTaSLO5wawgkRup-frontend
license:              BSD-2-Clause
copyright:            (c) Andy Gill, Simon Marlow
maintainer:           https://github.com/haskell/happy
author:               Andy Gill and Simon Marlow
stability:            stable
homepage:             https://www.haskell.org/happy/
synopsis:
    Happy is a parser generator for Haskell implemented using this library

description:
    Happy is a parser generator for Haskell.  Given a grammar
    specification in BNF, Happy generates Haskell code to parse the
    grammar.  Happy works in a similar way to the @yacc@ tool for C.

    This library provides the following functionality:

      * Data type definitions for the Grammar AST type, capturing the information in .y-files (Happy.Grammar)

      * A parser for happy grammar files (.y) to produce a Grammar (Happy.Frontend.*)

      * Implementations of the text book algorithms that compute the LR action and
        goto tables for the given '\''Grammar'\'' (Happy.Tabular.*)

      * An LALR code generator to produce table-driven, deterministic parsing code
        in Haskell (Happy.Backend.LALR.*)

      * A (less maintained) GLR code generator to produce table-driven,
        non-deterministic parsing code in Haskell, where ambiguous parses produce
        multiple parse trees (Happy.Backend.GLR.*)

category:             Development
abi:                  8f711f19283da1c97548c71163c54c3a
exposed-modules:
    Happy.Frontend Happy.Frontend.AbsSyn Happy.Frontend.Mangler
    Happy.Frontend.PrettyGrammar

hidden-modules:
    Happy.Frontend.ParseMonad Happy.Frontend.ParseMonad.Class
    Happy.Frontend.Mangler.Monad Happy.Frontend.Parser
    Happy.Frontend.Lexer Happy.Frontend.ParamRules
    Happy.Frontend.AttrGrammar Happy.Frontend.AttrGrammar.Parser
    Happy.Frontend.AttrGrammar.Mangler

import-dirs:          /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happy-lib
hs-libraries:         HShappy-lib-2.1.6-7bjb9RLGTaSLO5wawgkRup-frontend
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    happy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar mtl-2.3.1
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-happy-lib/html/happy-lib.haddock
haddock-html:         /usr/share/doc/haskell-happy-lib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-happy-lib-z-backend-lalr
version:              2.1.6
package-name:         happy-lib
lib-name:             backend-lalr
id:                   happy-lib-2.1.6-3QtkpKclX776iZ3gwqvHkh-backend-lalr
key:                  happy-lib-2.1.6-3QtkpKclX776iZ3gwqvHkh-backend-lalr
license:              BSD-2-Clause
copyright:            (c) Andy Gill, Simon Marlow
maintainer:           https://github.com/haskell/happy
author:               Andy Gill and Simon Marlow
stability:            stable
homepage:             https://www.haskell.org/happy/
synopsis:
    Happy is a parser generator for Haskell implemented using this library

description:
    Happy is a parser generator for Haskell.  Given a grammar
    specification in BNF, Happy generates Haskell code to parse the
    grammar.  Happy works in a similar way to the @yacc@ tool for C.

    This library provides the following functionality:

      * Data type definitions for the Grammar AST type, capturing the information in .y-files (Happy.Grammar)

      * A parser for happy grammar files (.y) to produce a Grammar (Happy.Frontend.*)

      * Implementations of the text book algorithms that compute the LR action and
        goto tables for the given '\''Grammar'\'' (Happy.Tabular.*)

      * An LALR code generator to produce table-driven, deterministic parsing code
        in Haskell (Happy.Backend.LALR.*)

      * A (less maintained) GLR code generator to produce table-driven,
        non-deterministic parsing code in Haskell, where ambiguous parses produce
        multiple parse trees (Happy.Backend.GLR.*)

category:             Development
abi:                  c7ffcc1713f2f74df2a28b2c0af541da
exposed-modules:      Happy.Backend.LALR Happy.Backend.LALR.ProduceCode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happy-lib
hs-libraries:         HShappy-lib-2.1.6-3QtkpKclX776iZ3gwqvHkh-backend-lalr
depends:
    array-0.5.6.0 base-4.18.2.1
    happy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar
    happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular

haddock-interfaces:   /usr/share/doc/haskell-happy-lib/html/happy-lib.haddock
haddock-html:         /usr/share/doc/haskell-happy-lib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-happy-lib-z-backend-glr
version:              2.1.6
package-name:         happy-lib
lib-name:             backend-glr
id:                   happy-lib-2.1.6-3AUa2aXUZqXDQv1lNG0wMA-backend-glr
key:                  happy-lib-2.1.6-3AUa2aXUZqXDQv1lNG0wMA-backend-glr
license:              BSD-2-Clause
copyright:            (c) Andy Gill, Simon Marlow
maintainer:           https://github.com/haskell/happy
author:               Andy Gill and Simon Marlow
stability:            stable
homepage:             https://www.haskell.org/happy/
synopsis:
    Happy is a parser generator for Haskell implemented using this library

description:
    Happy is a parser generator for Haskell.  Given a grammar
    specification in BNF, Happy generates Haskell code to parse the
    grammar.  Happy works in a similar way to the @yacc@ tool for C.

    This library provides the following functionality:

      * Data type definitions for the Grammar AST type, capturing the information in .y-files (Happy.Grammar)

      * A parser for happy grammar files (.y) to produce a Grammar (Happy.Frontend.*)

      * Implementations of the text book algorithms that compute the LR action and
        goto tables for the given '\''Grammar'\'' (Happy.Tabular.*)

      * An LALR code generator to produce table-driven, deterministic parsing code
        in Haskell (Happy.Backend.LALR.*)

      * A (less maintained) GLR code generator to produce table-driven,
        non-deterministic parsing code in Haskell, where ambiguous parses produce
        multiple parse trees (Happy.Backend.GLR.*)

category:             Development
abi:                  ddb89d0ef3d95d22d0918e1a21b07292
exposed-modules:      Happy.Backend.GLR Happy.Backend.GLR.ProduceCode
import-dirs:          /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/happy-lib-2.1.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happy-lib
hs-libraries:         HShappy-lib-2.1.6-3AUa2aXUZqXDQv1lNG0wMA-backend-glr
depends:
    array-0.5.6.0 base-4.18.2.1
    happy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar
    happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular

haddock-interfaces:   /usr/share/doc/haskell-happy-lib/html/happy-lib.haddock
haddock-html:         /usr/share/doc/haskell-happy-lib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               happy-lib
version:            2.1.6
visibility:         public
id:                 happy-lib-2.1.6-7ULtXc23yfy8XmaSK0oiHZ
key:                happy-lib-2.1.6-7ULtXc23yfy8XmaSK0oiHZ
license:            BSD-2-Clause
copyright:          (c) Andy Gill, Simon Marlow
maintainer:         https://github.com/haskell/happy
author:             Andy Gill and Simon Marlow
stability:          stable
homepage:           https://www.haskell.org/happy/
synopsis:
    Happy is a parser generator for Haskell implemented using this library

description:
    Happy is a parser generator for Haskell.  Given a grammar
    specification in BNF, Happy generates Haskell code to parse the
    grammar.  Happy works in a similar way to the @yacc@ tool for C.

    This library provides the following functionality:

      * Data type definitions for the Grammar AST type, capturing the information in .y-files (Happy.Grammar)

      * A parser for happy grammar files (.y) to produce a Grammar (Happy.Frontend.*)

      * Implementations of the text book algorithms that compute the LR action and
        goto tables for the given '\''Grammar'\'' (Happy.Tabular.*)

      * An LALR code generator to produce table-driven, deterministic parsing code
        in Haskell (Happy.Backend.LALR.*)

      * A (less maintained) GLR code generator to produce table-driven,
        non-deterministic parsing code in Haskell, where ambiguous parses produce
        multiple parse trees (Happy.Backend.GLR.*)

category:           Development
abi:                6f78e70309fb6303857b6a05d0c7aa3c
exposed:            True
exposed-modules:
    Happy.Backend.GLR from happy-lib-2.1.6-3AUa2aXUZqXDQv1lNG0wMA-backend-glr:Happy.Backend.GLR,
    Happy.Backend.GLR.ProduceCode from happy-lib-2.1.6-3AUa2aXUZqXDQv1lNG0wMA-backend-glr:Happy.Backend.GLR.ProduceCode,
    Happy.Backend.LALR from happy-lib-2.1.6-3QtkpKclX776iZ3gwqvHkh-backend-lalr:Happy.Backend.LALR,
    Happy.Backend.LALR.ProduceCode from happy-lib-2.1.6-3QtkpKclX776iZ3gwqvHkh-backend-lalr:Happy.Backend.LALR.ProduceCode,
    Happy.Frontend from happy-lib-2.1.6-7bjb9RLGTaSLO5wawgkRup-frontend:Happy.Frontend,
    Happy.Frontend.AbsSyn from happy-lib-2.1.6-7bjb9RLGTaSLO5wawgkRup-frontend:Happy.Frontend.AbsSyn,
    Happy.Frontend.Mangler from happy-lib-2.1.6-7bjb9RLGTaSLO5wawgkRup-frontend:Happy.Frontend.Mangler,
    Happy.Frontend.PrettyGrammar from happy-lib-2.1.6-7bjb9RLGTaSLO5wawgkRup-frontend:Happy.Frontend.PrettyGrammar,
    Happy.Grammar from happy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar:Happy.Grammar,
    Happy.Grammar.ExpressionWithHole from happy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar:Happy.Grammar.ExpressionWithHole,
    Happy.Tabular from happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular:Happy.Tabular,
    Happy.Tabular.First from happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular:Happy.Tabular.First,
    Happy.Tabular.Info from happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular:Happy.Tabular.Info,
    Happy.Tabular.LALR from happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular:Happy.Tabular.LALR,
    Happy.Tabular.NameSet from happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular:Happy.Tabular.NameSet

data-dir:           /usr/share/haskell-happy-lib
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    happy-lib-2.1.6-3AUa2aXUZqXDQv1lNG0wMA-backend-glr
    happy-lib-2.1.6-3QtkpKclX776iZ3gwqvHkh-backend-lalr
    happy-lib-2.1.6-7bjb9RLGTaSLO5wawgkRup-frontend
    happy-lib-2.1.6-GMOa0u6yxgLfsNVdVzRmd-grammar
    happy-lib-2.1.6-IAaVarrJtY38joOXkunqWf-tabular mtl-2.3.1
    transformers-0.6.1.0

haddock-interfaces: /usr/share/doc/haskell-happy-lib/html/happy-lib.haddock
haddock-html:       /usr/share/doc/haskell-happy-lib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

